@@ -4,12 +4,13 @@ from urllib.parse import urlparse
 class ClarifaiModuleUrlHelper(object):
   """Lots of helper functionality for dealing with urls around modules."""
 
-  def __init__(self, auth):
+  def __init__(self, auth, module_manager_imv_id="module_manager_install"):
     """
         Args:
           auth: a ClarifaiAuthHelper object.
         """
     self._auth = auth
+    self._module_manager_imv_id = module_manager_imv_id
 
   @property
   def auth(self):
@@ -28,8 +29,8 @@ class ClarifaiModuleUrlHelper(object):
   def module_install_ui_url(self, dest_user_id, dest_app_id, module_url):
     """This is a url that allows for installation of the module from the community at 'module_url'
         into the destination app_id of the destination user_id."""
-    return ("%s/%s/%s/installed_module_versions/module_manager_install?page=install&install=%s" %
-            (self.auth.ui, dest_user_id, dest_app_id, module_url))
+    return ("%s/%s/%s/installed_module_versions/%s?page=install&install=%s" %
+            (self.auth.ui, self._module_manager_imv_id, dest_user_id, dest_app_id, module_url))
 
   @classmethod
   def split_module_ui_url(cls, install):
